complete -c onefetch -s d -l disabled-fields -d 'Allows you to disable FIELD(s) from appearing in the output' -r -f -a "project\t''
description\t''
head\t''
pending\t''
version\t''
created\t''
languages\t''
dependencies\t''
authors\t''
last-change\t''
contributors\t''
url\t''
commits\t''
churn\t''
lines-of-code\t''
size\t''
license\t''"
complete -c onefetch -l number-of-authors -d 'Maximum NUM of authors to be shown' -r
complete -c onefetch -l number-of-languages -d 'Maximum NUM of languages to be shown' -r
complete -c onefetch -l number-of-file-churns -d 'Maximum NUM of file churns to be shown' -r
complete -c onefetch -l churn-pool-size -d 'Minimum NUM of commits from HEAD used to compute the churn summary' -r
complete -c onefetch -s e -l exclude -d 'Ignore all files & directories matching EXCLUDE' -r
complete -c onefetch -l no-bots -d 'Exclude [bot] commits. Use <REGEX> to override the default pattern' -r
complete -c onefetch -s T -l type -d 'Filters output by language type' -r -f -a "programming\t''
markup\t''
prose\t''
data\t''"
complete -c onefetch -s t -l text-colors -d 'Changes the text colors (X X X...)' -r
complete -c onefetch -l number-separator -d 'Which thousands SEPARATOR to use' -r -f -a "plain\t''
comma\t''
space\t''
underscore\t''"
complete -c onefetch -l ascii-input -d 'Takes a non-empty STRING as input to replace the ASCII logo' -r -f -a "(__fish_complete_command)"
complete -c onefetch -s c -l ascii-colors -d 'Colors (X X X...) to print the ascii art' -r
complete -c onefetch -s a -l ascii-language -d 'Which LANGUAGE\'s ascii art to print' -r -f -a "nim\t''
julia\t''
text\t''
swift\t''
html\t''
xsl\t''
graphql\t''
lua\t''
powershell\t''
modelica\t''
forth\t''
ruby\t''
scheme\t''
odin\t''
batch\t''
php\t''
xaml\t''
cmake\t''
fortranmodern\t''
systemverilog\t''
just\t''
python\t''
ocaml\t''
zsh\t''
protocol-buffers\t''
rust\t''
json\t''
elm\t''
d\t''
verilog\t''
slang\t''
go\t''
openscad\t''
coffeescript\t''
racket\t''
assembly\t''
solidity\t''
sql\t''
zig\t''
cuda\t''
jsonnet\t''
r\t''
clojure\t''
purescript\t''
fish\t''
coldfusion\t''
qml\t''
hlsl\t''
gdscript\t''
bash\t''
vala\t''
raku\t''
autohotkey\t''
c++\t''
emacs-lisp\t''
glsl\t''
razor\t''
c\t''
svelte\t''
dart\t''
nix\t''
tcl\t''
jupyter-notebooks\t''
visualbasic\t''
pascal\t''
objective-c\t''
markdown\t''
vhdl\t''
perl\t''
prolog\t''
emojicode\t''
groovy\t''
webassembly\t''
abnf\t''
holyc\t''
ats\t''
sass\t''
vue\t''
xml\t''
org\t''
vimscript\t''
nushell\t''
svg\t''
dockerfile\t''
c#\t''
fortran\t''
ceylon\t''
java\t''
wolfram\t''
haxe\t''
idris\t''
oz\t''
yaml\t''
slint\t''
kotlin\t''
jsx\t''
typescript\t''
ada\t''
shell\t''
typst\t''
elixir\t''
coq\t''
javascript\t''
mojo\t''
crystal\t''
llvm\t''
tex\t''
toml\t''
gleam\t''
lisp\t''
tsx\t''
abap\t''
agda\t''
f#\t''
arduino\t''
hcl\t''
erlang\t''
processing\t''
renpy\t''
haskell\t''
css\t''
scala\t''
makefile\t''
lean\t''"
complete -c onefetch -l true-color -d 'Specify when to use true color' -r -f -a "auto\t''
never\t''
always\t''"
complete -c onefetch -s i -l image -d 'Path to the IMAGE file' -r -F
complete -c onefetch -l image-protocol -d 'Which image PROTOCOL to use' -r -f -a "kitty\t''
sixel\t''
iterm\t''"
complete -c onefetch -l color-resolution -d 'VALUE of color resolution to use with SIXEL backend' -r -f -a "16\t''
32\t''
64\t''
128\t''
256\t''"
complete -c onefetch -s o -l output -d 'Outputs Onefetch in a specific format' -r -f -a "json\t''
yaml\t''"
complete -c onefetch -l generate -d 'If provided, outputs the completion file for given SHELL' -r -f -a "bash\t''
elvish\t''
fish\t''
powershell\t''
zsh\t''"
complete -c onefetch -l no-title -d 'Hides the title'
complete -c onefetch -l no-merges -d 'Ignores merge commits'
complete -c onefetch -s E -l email -d 'Show the email address of each author'
complete -c onefetch -l http-url -d 'Display repository URL as HTTP'
complete -c onefetch -l hide-token -d 'Hide token in repository URL'
complete -c onefetch -l include-hidden -d 'Count hidden files and directories'
complete -c onefetch -s z -l iso-time -d 'Use ISO 8601 formatted timestamps'
complete -c onefetch -l no-bold -d 'Turns off bold formatting'
complete -c onefetch -l no-color-palette -d 'Hides the color palette'
complete -c onefetch -l no-art -d 'Hides the ascii art or image if provided'
complete -c onefetch -l nerd-fonts -d 'Use Nerd Font icons'
complete -c onefetch -s l -l languages -d 'Prints out supported languages'
complete -c onefetch -s p -l package-managers -d 'Prints out supported package managers'
complete -c onefetch -s h -l help -d 'Print help (see more with \'--help\')'
complete -c onefetch -s V -l version -d 'Print version'
